setwd("/spider_finna/seurat")
library(Seurat)
library(dplyr)
library(patchwork)
library(ggplot2)
library("Nebulosa")
library("Seurat")
library("BiocFileCache")
library("DoubletFinder")
load("obj.Rda")
dim(seurat_object)
VlnPlot(seurat_object, features = c("nFeature_RNA", "nCount_RNA", "percent.mt"), ncol = 3)
ggsave("plot2.pdf", width = 28, height = 25, units = "cm")

## QC
plot1 <- FeatureScatter(seurat_object, feature1 = "nCount_RNA", feature2 = "percent.mt")
plot2 <- FeatureScatter(seurat_object, feature1 = "nCount_RNA", feature2 = "nFeature_RNA")
plot1 + plot2
ggsave("plot3.pdf", width = 28, height = 25, units = "cm")

#LogNormalize：A = log( 1 + ( UMIA ÷ UMITotal ) × 10000 ) 
seurat_object <- NormalizeData(seurat_object, normalization.method = "LogNormalize", scale.factor = 10000)

seurat_object <- FindVariableFeatures(seurat_object, selection.method = "vst", nfeatures = 2000)
#
top10 <- head(VariableFeatures(seurat_object), 10)
top10
#
plot3 <- VariableFeaturePlot(seurat_object)+NoLegend()
plot4 <- LabelPoints(plot = plot3, points = top10, repel = TRUE, xnudge=0, ynudge=0)
plot3+plot4
ggsave("plot4.pdf", width = 28, height = 25, units = "cm")

#
all.genes <- rownames(seurat_object)
seurat_object <- ScaleData(seurat_object, features = all.genes, vars.to.regress = "percent.mt")
seurat_object <- RunPCA(seurat_object, features = VariableFeatures(object = seurat_object)) 
# 
print(seurat_object[["pca"]], dims = 1:12, nfeatures = 3) 
#
DimPlot(seurat_object, reduction = "pca")+ NoLegend() 
#
DimHeatmap(seurat_object, dims = 1:2, cells = 500, balanced = TRUE) 
ggsave("plot2.png", width = 28, height = 25, units = "cm")

#
##Jackstraw 
seurat_object <- JackStraw(seurat_object, num.replicate = 100)
seurat_object <- ScoreJackStraw(seurat_object, dims = 1:20) 
JackStrawPlot(seurat_object, dims = 1:15)
#
ElbowPlot(seurat_object)


#nearest neighbor graph
seurat_object <- FindNeighbors(seurat_object, dims = 1:10)
#resolution 
seurat_object <- FindClusters(seurat_object, resolution = 0.25) 
#
head(Idents(seurat_object), 12) 

#UMAP
seurat_object <- RunUMAP(seurat_object, dims = 1:10)
head(seurat_object@reductions$umap@cell.embeddings)
#DimPlot
umapplot <- DimPlot(seurat_object, reduction = "umap",pt.size = 1,label = T)
umapplot
table(seurat_object$seurat_clusters)

ggsave("umap_dim10.pdf", width = 28, height = 25, units = "cm")

logFCfilter=0.5
adjPvalFilter=0.05
pbmc.markers <- FindAllMarkers(object = seurat_object,
                               only.pos = FALSE,
                               min.pct = 0.25,
                               logfc.threshold = logFCfilter)

sig.makers=pbmc.markers[(abs(as.numeric(as.vector(pbmc.markers$avg_log2FC))) > logFCfilter & as.numeric(as.vector(pbmc.markers$p_val_adj))<adjPvalFilter),]
write.table(sig.makers, file = "makers.xls", sep = "\t", row.names = F, quote = F)
