setwd("/spider_finna/monocle")
library(monocle)
library(Seurat)
library(ggplot2)
library(cowplot)
library(dplyr)
load("../ScRNA.Rda")

####################
# Tail_cell_annalysis
data = as(as.matrix(seurat_object@assays$RNA@data), "sparseMatrix")
pd = new("AnnotatedDataFrame", data = seurat_object@meta.data)
fData = data.frame(gene_short_name = row.names(data), row.names = row.names(data))
fd = new("AnnotatedDataFrame", data = fData)
clustered_pbmc_monocle = newCellDataSet(data, phenoData = pd, featureData = fd, 
                                        lowerDetectionLimit = 0, expressionFamily = negbinomial.size())

clustered_pbmc_monocle <- estimateSizeFactors(clustered_pbmc_monocle)
clustered_pbmc_monocle <- estimateDispersions(clustered_pbmc_monocle, parallel = T)

logFCfilter=0.5
adjPvalFilter=0.05
seurat_object.markers <- FindAllMarkers(object = seurat_object,
                                        only.pos = FALSE,
                                        min.pct = 0.25,
                                        logfc.threshold = logFCfilter)

top5 <- seurat_object.markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_log2FC)
id <- unique(top5$gene)

Mono.cds <- setOrderingFilter(clustered_pbmc_monocle, id)
Mono.cds <- reduceDimension(
  Mono.cds,
  max_components = 2,
  method = 'DDRTree')
#psudotime
Mono.cds <- orderCells(Mono.cds)
clors2 <- c("#ff9f34","#f8c166","#49c7f6","#79d3fd","#d0ea79","#9fddfc","#edf8c6","#d0f0fd","#c3e252","#d0ea79")

plot1 <- plot_cell_trajectory(Mono.cds,cell_size = 1.0,color_by = "State")
plot2 <- plot_cell_trajectory(Mono.cds,cell_size = 1.0,color_by = "seurat_clusters")+ 
  scale_colour_manual(values = clors2)

plot_grid(plot1, plot2)

ggsave("Trajectory_plot1_plot2_1.pdf", width = 28, height = 15, units = "cm")